        subroutine rd_bsst(in_file,hdr,ncol,nrow,sst,pclr,ier)
c
c    Subroutine used to read in bayesian sst product's head info by
c    calling rd_bsst_hd, sst and pclr data by calling rd_bsst_data.
c    Input: in_file, maxsize
c    Output: hdr, ncol, nrow, sst, pclr, ier
c      with
c    character*128    in_file
c    character*256    hdr
c    integer          ncol, nrow, ier
c    integer*1        sst(mm), pclr(mm), with mm=ncol*nrow
c    ier=0 means reading is successful, otherwise there is an error
c
c*********read product binary file with header **********
c
      implicit        none
      character*128   in_file
      character*256   hdr
      integer         ncol, nrow, ier, krow, j
      integer*1       sst(ncol*nrow), pclr(ncol*nrow)

      ier=0

      call rd_bsst_hd(in_file,hdr,ncol, nrow, ier)

      if (ier .eq. -1) then
         write(6,*) "Size of SST data does NOT match..."
         return
      endif

      do j=1, ncol*nrow
         sst(j)=0
         pclr(j)=0
      enddo

      if ( ier.eq.0 ) then
         call rd_bsst_data(in_file, ncol, nrow, sst, pclr, ier)
      endif

      return
      end

c**********************************************************************
      subroutine rd_bsst_hd(in_file,hdr,ncol,nrow,ier)
c
c  subroutine used to get head info of product binary file (e.g. sst1b**)
c  Input: in_file, which is the file name of product binary file
c  Output: hdr, which is head info in character format
c          ncol, nrow, which are No. of column and row of the product data
c          Also ier, which represent an error type:
c               ier=0 means successful, otherwise ier!=0
c*********************************************************
c
        implicit        none
        character*128   in_file
        character*256   hdr

        character*8     ver_in
        integer         nhrec
        real*4          x0, dx, y0, dy
        integer*4       iy, id, ih, im
        integer         iavh

        integer       icol, irow  ! -- from in_file, local
        integer       ncol, nrow  ! -- pass from main program 
        integer       ier, ios1

        logical       infile_exists

c            for sgi - wordlen=4 ;   linux - wordlen=1
c       integer wordlen
c       parameter       (wordlen = 1)
c===============================
        INCLUDE 	"word_length.inc"
c==============================

      ier=0
      icol=0
      irow=0
      hdr(1:256)=' '

      inquire( file = in_file, exist = infile_exists )
      if ( .not. infile_exists ) then
        write(6,*)'rd_bsst_hd -- file does not exist: ',in_file
        ier=1
        return
      else
         open  ( 7,
     *           file    = in_file,
     *           status  = 'old',
     *           form    = 'unformatted',
     *           access  = 'direct',
     *           recl    = 256,
     *           iostat  = ier,
     *           err     = 55
     *          )
         read (7,rec=1,iostat=ier,err=66)  hdr(1:256)
         close (7)


c   Convert character type head info 'hdr' into corresponding type
c   The reason to do so is to get integer type of 'icol' and 'irow'
c   and compared them with ncol and nrow.
c---------------------------------------
         read(hdr,100,err=22,end=22,iostat=ios1) ver_in,icol,nhrec,
     *           irow,x0,dx,y0,dy, iy,id,ih,im,iavh
  100    format( a8,i6,i4,i6,2x,2(f9.3,f6.3),i8.4,i4.3,2i3.2,i5)
  22     write(6,*)  'Read hdr -- iostat=', ios1
         if (icol.ne.ncol .or. irow.ne.nrow) then
            write(6,*) "The size of column and row are NOT match:"
            write(6,*) "From main, ncol=",ncol,", nrow=",nrow
            write(6,*) "From rd_bsst_hd,icol=",icol,", irow=",irow
            ier=-1
         endif
         return
      endif

   55   ier = 1000 + ier
        return
   66   ier = 2000 + ier
        return
      end

c*********************************************************
      subroutine rd_bsst_data(in_file,ncol,nrow,sst,pclr,ier)
c
c  subroutine to read in the SST and PCLR from product binary file with head
c  Input: in_file, ncol,nrow
c  Output: sst, pclr, ier
c*********************************************************
c
      implicit        none
      integer        ncol, nrow, krow, j, ier, irec
      character*128  in_file
c      integer*1      sst(ncol,nrow), pclr(ncol,nrow)
      integer*1 tmp(ncol)
      integer*1 sst(ncol*nrow), pclr(ncol*nrow)

c         for sgi - wordlen=4 ;   linux - wordlen=1
c     integer wordlen
c     parameter       (wordlen = 1)

c======================================
      INCLUDE 		"word_length.inc"
c======================================

      write(6,*) 'Going to get data.....'
c
c     initialization
c------------------
      do j=1,ncol
            tmp(j)=0
      enddo
      do j=1,nrow*ncol
            sst( j)=0
            pclr(j)=0
      enddo
      ier=0

      open  ( 7,
     *        file    = in_file,
     *        status  = 'old',
     *        form    = 'unformatted',
     *        access  = 'direct',
     *        recl    = ncol/wordlen,
     *        iostat  = ier,
     *        err     = 55
     *          )

      irec=1

      write(6,*) ' rd_bsst_data ---- Going to read sst'
      do krow=1,nrow
         irec = irec+1
         read (7,rec=irec,iostat=ier,err=77) (tmp(j),j=1,ncol)
         do j=1,ncol
             sst( (krow-1)*ncol+j)=tmp(j)
         enddo
      enddo

      write(6,*) ' rd_bsst_data ---- Going to read pclr'
      do krow=1,nrow
         irec = irec+1
         read (7,rec=irec,iostat=ier,err=88) (tmp(j),j=1,ncol)
         do j=1,ncol
             pclr( (krow-1)*ncol+j)=tmp(j)
         enddo
      enddo

      write(6,*) 'rd_bsst_data -- finished data read from file ',
     *           in_file
      close(7)
      return
c
   55   ier = 1000 + ier
        return
   77   ier = 3000 + ier
        return
   88   ier = 4000 + ier
        return
        end

